compute abstract method
The computation function, a function used the same way as Flutter's compute function, but for a long lived isolate.
Implementation
Future<R> compute(
IsolateCallback<Q, R> callback,
Q message, {
String? debugLabel,
});
The computation function, a function used the same way as Flutter's compute function, but for a long lived isolate.
Future<R> compute(
IsolateCallback<Q, R> callback,
Q message, {
String? debugLabel,
});