computeStream abstract method
- @experimental
- IsolateStream<
Q, R> callback, - Q message, {
- String? debugLabel,
A computation function that returns a Stream of responses from the long lived isolate.
Very similar to the compute function, but instead of returning a Future, a Stream is returned to allow for a response in multiple parts. Every stream event will be sent individually through from the isolate.
Implementation
@experimental
Stream<R> computeStream(
IsolateStream<Q, R> callback,
Q message, {
String? debugLabel,
});